SecretVec

Struct SecretVec 

pub struct SecretVec { /* private fields */ }
A heap-allocated, variable-length secret that is automatically zeroed when dropped.

Use SecretVec when the key length is not known at compile time (e.g. RSA private keys, derived key material of arbitrary length).

Implementations

Source

impl SecretVec

pub fn new(bytes: Vec<u8>) -> Self

Create a SecretVec from a Vec<u8>.

pub fn from_slice(slice: &[u8]) -> Self

Create a SecretVec by copying from a slice.

pub fn as_bytes(&self) -> &[u8]

Borrow the secret bytes.

pub fn len(&self) -> usize

Return the length in bytes.

pub fn is_empty(&self) -> bool

Return true if the secret is empty.