pub struct SecretVec { /* private fields */ }Expand description
A heap-allocated, variable-length secret that is automatically zeroed when dropped.
Use SecretVec when the key length is not known at compile time (e.g.
RSA private keys, derived key material of arbitrary length).
Implementations